@@ -27,14 +27,16 @@
 #' @examples
 #' claim <- jwt_claim()
 #' str(claim)
-jwt_claim <- function(iss = NULL,
-                      sub = NULL,
-                      aud = NULL,
-                      exp = unix_time() + 5L * 60L,
-                      nbf = unix_time(),
-                      iat = unix_time(),
-                      jti = NULL,
-                      ...) {
+jwt_claim <- function(
+  iss = NULL,
+  sub = NULL,
+  aud = NULL,
+  exp = unix_time() + 5L * 60L,
+  nbf = unix_time(),
+  iat = unix_time(),
+  jti = NULL,
+  ...
+) {
   # https://datatracker.ietf.org/doc/html/rfc7519
   jose::jwt_claim(
     iss = iss,
@@ -65,7 +67,7 @@ jwt_encode_sig <- function(claim, key, size = 256, header = list()) {
 #' @export
 #' @rdname jwt_claim
 #' @param secret String or raw vector with a secret passphrase.
-jwt_encode_hmac <- function(claim, secret, size = size, header = list()) {
+jwt_encode_hmac <- function(claim, secret, size = 256, header = list()) {
   check_installed("jose")
-  jose::jwt_encode_sig(claim, secret, size = size, header = header)
+  jose::jwt_encode_hmac(claim, secret, size = size, header = header)
 }
