@@ -7,12 +7,13 @@ test_that("nothing happens if cache not enabled", {
 })
 
 test_that("never retrieves POST request from cache", {
-  req <- request("http://example.com") %>%
-    req_method("POST") %>%
+  req <- request("http://example.com") |>
+    req_method("POST") |>
     req_cache(tempfile())
 
   # Fake an equivalent GET request in the cache
-  resp <- response(200,
+  resp <- response(
+    200,
     headers = "Expires: Wed, 01 Jan 3000 00:00:00 GMT",
     body = charToRaw("abc")
   )
@@ -22,8 +23,9 @@ test_that("never retrieves POST request from cache", {
 })
 
 test_that("immutable objects retrieved directly from cache", {
-  req <- request("http://example.com") %>% req_cache(tempfile())
-  resp <- response(200,
+  req <- request("http://example.com") |> req_cache(tempfile())
+  resp <- response(
+    200,
     headers = "Expires: Wed, 01 Jan 3000 00:00:00 GMT",
     body = charToRaw("abc")
   )
@@ -33,12 +35,13 @@ test_that("immutable objects retrieved directly from cache", {
 })
 
 test_that("cached cache header added to request", {
-  req <- request("http://example.com") %>% req_cache(tempfile())
+  req <- request("http://example.com") |> req_cache(tempfile())
   # If not cached, request returned as is
   req2 <- cache_pre_fetch(req)
   expect_equal(req2, req)
 
-  resp <- response(200,
+  resp <- response(
+    200,
     headers = c('Etag: "abc"', "Last-Modified: Wed, 01 Jan 2020 00:00:00 GMT"),
     body = charToRaw("abc")
   )
@@ -46,12 +49,15 @@ test_that("cached cache header added to request", {
 
   # After caching adds caching headers
   req3 <- cache_pre_fetch(req)
-  expect_equal(req3$headers$`If-Modified-Since`, "Wed, 01 Jan 2020 00:00:00 GMT")
+  expect_equal(
+    req3$headers$`If-Modified-Since`,
+    "Wed, 01 Jan 2020 00:00:00 GMT"
+  )
   expect_equal(req3$headers$`If-None-Match`, '"abc"')
 })
 
 test_that("error can use cached value", {
-  req <- request("http://example.com") %>% req_cache(tempfile())
+  req <- request("http://example.com") |> req_cache(tempfile())
   resp <- response(200, body = charToRaw("OK"))
   cache_set(req, resp)
 
@@ -62,7 +68,7 @@ test_that("error can use cached value", {
 })
 
 test_that("304 retains headers but gets cached body", {
-  req <- request("http://example.com") %>% req_cache(tempfile())
+  req <- request("http://example.com") |> req_cache(tempfile())
   resp <- response(200, headers = "X: 1", body = charToRaw("OK"))
   cache_set(req, resp)
 
@@ -76,7 +82,7 @@ test_that("304 retains headers but gets cached body", {
 })
 
 test_that("automatically adds to cache", {
-  req <- request("http://example.com") %>% req_cache(tempfile())
+  req <- request("http://example.com") |> req_cache(tempfile())
   expect_true(is.null(cache_get(req)))
 
   resp <- response(200, headers = 'Etag: "abc"', body = charToRaw("OK"))
@@ -86,8 +92,9 @@ test_that("automatically adds to cache", {
 })
 
 test_that("cache emits useful debugging info", {
-  req <- request("http://example.com") %>% req_cache(tempfile(), debug = TRUE)
-  resp <- response(200,
+  req <- request("http://example.com") |> req_cache(tempfile(), debug = TRUE)
+  resp <- response(
+    200,
     headers = "Expires: Wed, 01 Jan 3000 00:00:00 GMT",
     body = charToRaw("abc")
   )
@@ -99,7 +106,7 @@ test_that("cache emits useful debugging info", {
     invisible(cache_pre_fetch(req))
   })
 
-  req <- request("http://example.com") %>%
+  req <- request("http://example.com") |>
     req_cache(tempfile(), debug = TRUE, use_on_error = TRUE)
   resp <- response(200, headers = "X: 1", body = charToRaw("OK"))
   cache_set(req, resp)
@@ -114,7 +121,7 @@ test_that("cache emits useful debugging info", {
 # cache -------------------------------------------------------------------
 
 test_that("can get and set from cache", {
-  req <- request("http://example.com") %>% req_cache(tempfile())
+  req <- request("http://example.com") |> req_cache(tempfile())
   resp <- response(
     200,
     headers = list(
@@ -157,7 +164,7 @@ test_that("can get and set from cache", {
 })
 
 test_that("handles responses with files", {
-  req <- request("http://example.com") %>% req_cache(tempfile())
+  req <- request("http://example.com") |> req_cache(tempfile())
 
   path <- local_write_lines("Hi there")
   resp <- response(200, headers = "Etag: ABC", body = new_path(path))
@@ -183,7 +190,7 @@ test_that("handles responses with files", {
 
 test_that("corrupt files are ignored", {
   cache_dir <- withr::local_tempdir()
-  req <- request("http://example.com") %>% req_cache(cache_dir)
+  req <- request("http://example.com") |> req_cache(cache_dir)
 
   writeLines(letters, req_cache_path(req))
   expect_true(is.null(cache_get(req)))
@@ -261,18 +268,23 @@ test_that("correctly determines if response is cacheable", {
   expect_equal(is_cacheable(200, headers = "Expires: ABC"), TRUE)
   expect_equal(is_cacheable(200, headers = "Cache-Control: max-age=10"), TRUE)
   expect_equal(is_cacheable(200, headers = "Etag: ABC"), TRUE)
-  expect_equal(is_cacheable(200, headers = c("Etag: ABC", "Cache-Control: no-store")), FALSE)
+  expect_equal(
+    is_cacheable(200, headers = c("Etag: ABC", "Cache-Control: no-store")),
+    FALSE
+  )
   expect_equal(is_cacheable(200), FALSE)
   expect_equal(is_cacheable(404), FALSE)
   expect_equal(is_cacheable(method = "POST"), FALSE)
 })
 
 test_that("can extract cache info with correct types", {
-  resp <- response(headers = c(
-    "Expires: Wed, 01 Jan 2020 00:00:00 GMT",
-    "Last-Modified: Wed, 01 Jan 2010 00:00:00 GMT",
-    "Etag: \"abc\""
-  ))
+  resp <- response(
+    headers = c(
+      "Expires: Wed, 01 Jan 2020 00:00:00 GMT",
+      "Last-Modified: Wed, 01 Jan 2010 00:00:00 GMT",
+      "Etag: \"abc\""
+    )
+  )
   info <- resp_cache_info(resp)
 
   expect_equal(info$expires, local_time("2020-01-01"))
@@ -284,17 +296,21 @@ test_that("can extract cache info with correct types", {
 
 test_that("can extract various expiry values", {
   # Prefer Date + max-age
-  resp1 <- response(headers = c(
-    "Date: Wed, 01 Jan 2020 00:00:00 GMT",
-    "Cache-Control: max-age=3600",
-    "Expiry: Wed, 01 Jan 2020 00:00:00 GMT"
-  ))
+  resp1 <- response(
+    headers = c(
+      "Date: Wed, 01 Jan 2020 00:00:00 GMT",
+      "Cache-Control: max-age=3600",
+      "Expiry: Wed, 01 Jan 2020 00:00:00 GMT"
+    )
+  )
   expect_equal(resp_cache_expires(resp1), local_time("2020-01-01 01:00"))
 
   # Fall back to Expires
-  resp2 <- response(headers = c(
-    "Expires: Wed, 01 Jan 2020 00:00:00 GMT"
-  ))
+  resp2 <- response(
+    headers = c(
+      "Expires: Wed, 01 Jan 2020 00:00:00 GMT"
+    )
+  )
   expect_equal(resp_cache_expires(resp2), local_time("2020-01-01 00:00"))
 
   # Returns NA if no expiry
